@@ -8,13 +8,38 @@
 
 import sys
 import argparse
-from loguru import logger
+import subprocess
+import logging
+from pathlib import Path
 from dfwsgroup import __description__, __version__
 from dfwsgroup.common.command import init_parser_command, main_command
 from dfwsgroup.common.scaffold import main_scaffold, init_parser_scaffold
 
 
+def install_package():
+    """
+    - 更新pip
+    - 安装python依赖包
+    :return:
+    """
+    douban_com = "https://pypi.douban.com/smiple/"
+    path = Path(
+        __file__
+    ).parent.parent.joinpath("requirements.txt")
+    args = [
+        f"python -m pip install --upgrade pip -i {douban_com}",
+        f"python -m pip install -r {path} -i {douban_com}",
+    ]
+    for i in args:
+        results = subprocess.run(i)
+    return results.returncode
+
+
 def main():
+    """
+    - 运行命令
+    :return:
+    """
     parser = argparse.ArgumentParser(description=__description__)
     parser.add_argument(
         "-V", "--version", dest="version", action="store_true", help="show version"
@@ -33,5 +58,5 @@ def main():
         if parser.parse_args().version:
             print(f"version：{__version__}")
     else:
-        logger.error(f"{sys.argv[1:]}")
+        logging.error(f"{sys.argv[1:]}")
         raise Exception
